@@ -31,7 +31,7 @@ class Consumer(BaseClient):
             self.channel.basic_consume(
                 queue=self.queue,
                 on_message_callback=self._callback_method,
-                auto_ack=False
+                auto_ack=True
             )
 
             logger.info(f'{self.name} initialized')
