@@ -66,10 +66,11 @@ class ObjectDetectionStub(Stub):
             destination='object_detection'
         )
 
-    def find(self, image_id:int, image:np.ndarray) -> None:
+    def find(self, camera_id:int, image_id:int, image:np.ndarray) -> None:
         self._send(
             primitive='find',  
             content={
+                'camera_id': camera_id,
                 'image_id': image_id,
                 'image': image
             }
